==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/outputs/GuestAgentInstallStatusResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Defines the status of a guest agent installation.
 * @property agentVersion The hybrid machine agent full version.
 * @property errorDetails Details about the error state.
 * @property lastStatusChange The time of the last status change.
 * @property status The installation status of the hybrid machine agent installation.
 * @property vmUuid Specifies the VM's unique SMBIOS ID.
 */
public data class GuestAgentInstallStatusResponse(
    public val agentVersion: String,
    public val errorDetails: List<ErrorDetailResponse>,
    public val lastStatusChange: String,
    public val status: String,
    public val vmUuid: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.azurestackhci.outputs.GuestAgentInstallStatusResponse):
            GuestAgentInstallStatusResponse = GuestAgentInstallStatusResponse(
            agentVersion = javaType.agentVersion(),
            errorDetails = javaType.errorDetails().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.azurestackhci.kotlin.outputs.ErrorDetailResponse.Companion.toKotlin(args0)
                })
            }),
            lastStatusChange = javaType.lastStatusChange(),
            status = javaType.status(),
            vmUuid = javaType.vmUuid(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/outputs/GuestAgentInstallStatusResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Defines the status of a guest agent installation.
 * @property agentVersion The hybrid machine agent full version.
 * @property errorDetails Details about the error state.
 * @property lastStatusChange The time of the last status change.
 * @property status The installation status of the hybrid machine agent installation.
 * @property vmUuid Specifies the VM's unique SMBIOS ID.
 */
public data class GuestAgentInstallStatusResponse(
    public val agentVersion: String,
    public val errorDetails: List<ErrorDetailResponse>,
    public val lastStatusChange: String,
    public val status: String,
    public val vmUuid: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.azurestackhci.outputs.GuestAgentInstallStatusResponse): GuestAgentInstallStatusResponse = GuestAgentInstallStatusResponse(
            agentVersion = javaType.agentVersion(),
            errorDetails = javaType.errorDetails().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.azurestackhci.kotlin.outputs.ErrorDetailResponse.Companion.toKotlin(args0)
                })
            }),
            lastStatusChange = javaType.lastStatusChange(),
            status = javaType.status(),
            vmUuid = javaType.vmUuid(),
        )
    }
}
